@@ -46,6 +46,8 @@ NotoSansCJK = bsepth + r'typeface/NotoSansCJKsc-Regular.otf'
 NotoColorEmoji = bsepth + r'typeface/NotoColorEmoji.ttf'
 CODE2000 = bsepth + r'typeface/CODE2000.ttf'
 Unifont = bsepth + r'typeface/Unifont.ttf.ttf'
+arial = bsepth + r'typeface/reserve/arial.ttf'
+himalaya = bsepth + r'typeface/reserve/himalaya.ttf'
 
 
 rtime = []
@@ -56,21 +58,26 @@ euniMap = efont['cmap'].tables[0].ttFont.getBestCmap()
 Cfont = TTFont(CODE2000)
 cuniMap = Cfont['cmap'].tables[0].ttFont.getBestCmap()
 
-# tfl = [[f.fname, f.name, f.style] for f in fontManager.ttflist]
-# f = fontManager.ttflist
+tfl = [[f.fname, f.name, f.style] for f in fontManager.ttflist]
+f = fontManager.ttflist
 okf = []
 
-# for f in tfl:
-#     f_path = Path(f[0])
-#     try:
-#         if f_path.suffix not in ['.ttf', '.TTF', '.otf', '.OTF']:
-#             print(f'字体{f[0]}不符合样式需求，已经排除。')
-#             continue
-#         oofont = TTFont(f[0])
-#         oouniMap = oofont['cmap'].tables[0].ttFont.getBestCmap()
-#         okf.append([oouniMap, f[0]])
-#     except:
-#         print(f'导入{f[0]}失败，无需处理')
+for f in tfl:
+    f_path = Path(f[0])
+    try:
+        if f_path.suffix not in ['.ttf', '.TTF', '.otf', '.OTF']:
+            print(f'字体{f[0]}不符合样式需求，已经排除。')
+            continue
+        oofont = TTFont(f[0])
+        oouniMap = oofont['cmap'].tables[0].ttFont.getBestCmap()
+        okf.append([oouniMap, f[0]])
+    except:
+        print(f'导入{f[0]}失败，无需处理')
+
+# 加入后备字体
+okf.append([TTFont(arial)['cmap'].tables[0].ttFont.getBestCmap(), arial])
+okf.append([TTFont(himalaya)['cmap'].tables[0].ttFont.getBestCmap(), himalaya])
+
 
 
 class info(BaseModel):
@@ -794,8 +801,13 @@ class DynamicPictureRendering:
             elif el['f'] == MainFont:
                 img_draw.text(el['d'], el['t'], font=MainFont, fill=el['c'])
             else:
-                oFont = ImageFont.truetype(el['f'], FOUNT_SIZE)
-                img_draw.text(el['d'], el['t'], font=oFont, fill=el['c'])
+                try:
+                    oFont = ImageFont.truetype(el['f'], FOUNT_SIZE)
+                    img_draw.text(el['d'], el['t'], font=oFont, fill=el['c'])
+                except:
+                    print(f"字库中不存在字符{el['t']}，请检查字库是否完整")
+                    oFont = ImageFont.truetype(CODE2000, FOUNT_SIZE)
+                    img_draw.text(el['d'], "⎕", font=oFont, fill=el['c'])
 
         # ISDO 异步下载表情包
         # TODO 复用下载后的对象，下载了之后直接调用，就不要在去磁盘里打开了
